pub mod syslog_trait;

//-- SYNC MUTEX
#[cfg(feature = "use_atomic_block")]
mod mutex;
#[cfg(feature = "use_atomic_block")]
mod poison;


//-- SYNC --
#[cfg(feature = "use_sync")]
pub mod syslog_sync;

//-- SYNC QUEUE --
#[cfg(feature = "use_sync_queue")]
pub mod syslog_sync_queue;

pub mod syslog_stream;

pub mod syslog_sync_internal;

//-- SYNC SOCKET --
#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
mod socket;